import { NativeEventEmitter, NativeModules } from 'react-native';
const {
  IONPortalPubSub,
  IONPortalManager,
  IONLiveUpdatesManager
} = NativeModules;
export { default as PortalView } from './PortalView';
const PortalsPubSub = new NativeEventEmitter(IONPortalPubSub);
const subscriptionMap = new Map();
export const subscribe = async (topic, onMessageReceived) => {
  const subscriptionRef = await IONPortalPubSub.subscribe(topic);
  const subscriber = PortalsPubSub.addListener('PortalsSubscription', message => {
    if (message.subscriptionRef === subscriptionRef) {
      onMessageReceived(message);
    }
  });
  subscriptionMap.set(subscriptionRef, subscriber);
  return subscriptionRef;
};
export const unsubscribe = (topic, subRef) => {
  IONPortalPubSub.unsubscribe(topic, subRef);
  const subscription = subscriptionMap.get(subRef);

  if (subscription !== undefined) {
    subscription.remove();
    subscriptionMap.delete(subRef);
  }
};
export const publish = (topic, data) => {
  const msg = {
    message: data
  };
  IONPortalPubSub.publish(topic, msg);
};
export const register = key => {
  IONPortalManager.register(key);
};
export const addPortal = portal => {
  IONPortalManager.addPortal(portal);
};
export const syncOne = appId => {
  return IONLiveUpdatesManager.syncOne(appId);
};
export const syncSome = appIds => {
  return IONLiveUpdatesManager.syncSome(appIds);
};
export const syncAll = () => {
  return IONLiveUpdatesManager.syncAll();
};
//# sourceMappingURL=index.js.map