import { ViewProps } from 'react-native';
export { default as PortalView } from './PortalView';
export interface Message {
    subscriptionRef: number;
    data: any;
    topic: string;
}
export declare const subscribe: (topic: string, onMessageReceived: (message: Message) => void) => Promise<number>;
export declare const unsubscribe: (topic: string, subRef: number) => void;
export declare const publish: (topic: string, data: any) => void;
export declare const register: (key: string) => void;
export interface Portal {
    name: string;
    androidPlugins?: string[];
    startDir?: string;
    initialContext?: {
        [key: string]: any;
    };
    liveUpdate?: LiveUpdateConfig;
}
export declare type PortalProps = Pick<Portal, 'name' | 'initialContext'> & ViewProps;
export declare const addPortal: (portal: Portal) => void;
export interface LiveUpdate {
    appId: string;
    channel: string;
}
export declare type LiveUpdateConfig = LiveUpdate & {
    syncOnAdd: boolean;
};
export interface LiveUpdateError {
    appId: string;
    failStep: string;
    message: string;
}
export interface SyncResults {
    liveUpdates: LiveUpdate[];
    errors: LiveUpdateError[];
}
export declare const syncOne: (appId: string) => Promise<LiveUpdate>;
export declare const syncSome: (appIds: string[]) => Promise<SyncResults>;
export declare const syncAll: () => Promise<SyncResults>;
